@@ -13,12 +13,20 @@ Usage::
     client: OpenSearchServiceClient = session.client("opensearch")
     ```
 """
-import sys
 from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import EngineTypeType, LogTypeType, OpenSearchPartitionInstanceTypeType
+from .literals import (
+    ActionTypeType,
+    ConnectionModeType,
+    DryRunModeType,
+    EngineTypeType,
+    LogTypeType,
+    OpenSearchPartitionInstanceTypeType,
+    PackageTypeType,
+    ScheduleAtType,
+)
 from .type_defs import (
     AcceptInboundConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
@@ -29,6 +37,7 @@ from .type_defs import (
     CancelServiceSoftwareUpdateResponseTypeDef,
     ClusterConfigTypeDef,
     CognitoOptionsTypeDef,
+    ConnectionPropertiesTypeDef,
     CreateDomainResponseTypeDef,
     CreateOutboundConnectionResponseTypeDef,
     CreatePackageResponseTypeDef,
@@ -41,8 +50,11 @@ from .type_defs import (
     DescribeDomainAutoTunesResponseTypeDef,
     DescribeDomainChangeProgressResponseTypeDef,
     DescribeDomainConfigResponseTypeDef,
+    DescribeDomainHealthResponseTypeDef,
+    DescribeDomainNodesResponseTypeDef,
     DescribeDomainResponseTypeDef,
     DescribeDomainsResponseTypeDef,
+    DescribeDryRunProgressResponseTypeDef,
     DescribeInboundConnectionsResponseTypeDef,
     DescribeInstanceTypeLimitsResponseTypeDef,
     DescribeOutboundConnectionsResponseTypeDef,
@@ -66,6 +78,7 @@ from .type_defs import (
     ListDomainsForPackageResponseTypeDef,
     ListInstanceTypeDetailsResponseTypeDef,
     ListPackagesForDomainResponseTypeDef,
+    ListScheduledActionsResponseTypeDef,
     ListTagsResponseTypeDef,
     ListVersionsResponseTypeDef,
     ListVpcEndpointAccessResponseTypeDef,
@@ -73,25 +86,22 @@ from .type_defs import (
     ListVpcEndpointsResponseTypeDef,
     LogPublishingOptionTypeDef,
     NodeToNodeEncryptionOptionsTypeDef,
+    OffPeakWindowOptionsTypeDef,
     PackageSourceTypeDef,
     PurchaseReservedInstanceOfferingResponseTypeDef,
     RejectInboundConnectionResponseTypeDef,
     SnapshotOptionsTypeDef,
+    SoftwareUpdateOptionsTypeDef,
     StartServiceSoftwareUpdateResponseTypeDef,
     TagTypeDef,
     UpdateDomainConfigResponseTypeDef,
     UpdatePackageResponseTypeDef,
+    UpdateScheduledActionResponseTypeDef,
     UpdateVpcEndpointResponseTypeDef,
     UpgradeDomainResponseTypeDef,
     VPCOptionsTypeDef,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("OpenSearchServiceClient",)
 
 
@@ -108,6 +118,7 @@ class Exceptions:
     BaseException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
+    DependencyFailureException: Type[BotocoreClientError]
     DisabledOperationException: Type[BotocoreClientError]
     InternalException: Type[BotocoreClientError]
     InvalidPaginationTokenException: Type[BotocoreClientError]
@@ -115,6 +126,7 @@ class Exceptions:
     LimitExceededException: Type[BotocoreClientError]
     ResourceAlreadyExistsException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
+    SlotNotAvailableException: Type[BotocoreClientError]
     ValidationException: Type[BotocoreClientError]
 
 
@@ -140,7 +152,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> AcceptInboundConnectionResponseTypeDef:
         """
         Allows the destination Amazon OpenSearch Service domain owner to accept an
-        inbound cross-cluster search connection request.
+        inbound cross-cluster search connection
+        request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#accept_inbound_connection)
@@ -169,7 +182,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> AuthorizeVpcEndpointAccessResponseTypeDef:
         """
         Provides access to an Amazon OpenSearch Service domain through the use of an
-        interface VPC endpoint.
+        interface VPC
+        endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.authorize_vpc_endpoint_access)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#authorize_vpc_endpoint_access)
@@ -220,7 +234,9 @@ class OpenSearchServiceClient(BaseClient):
         DomainEndpointOptions: DomainEndpointOptionsTypeDef = ...,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
         TagList: Sequence[TagTypeDef] = ...,
-        AutoTuneOptions: AutoTuneOptionsInputTypeDef = ...
+        AutoTuneOptions: AutoTuneOptionsInputTypeDef = ...,
+        OffPeakWindowOptions: OffPeakWindowOptionsTypeDef = ...,
+        SoftwareUpdateOptions: SoftwareUpdateOptionsTypeDef = ...
     ) -> CreateDomainResponseTypeDef:
         """
         Creates an Amazon OpenSearch Service domain.
@@ -234,11 +250,14 @@ class OpenSearchServiceClient(BaseClient):
         *,
         LocalDomainInfo: DomainInformationContainerTypeDef,
         RemoteDomainInfo: DomainInformationContainerTypeDef,
-        ConnectionAlias: str
+        ConnectionAlias: str,
+        ConnectionMode: ConnectionModeType = ...,
+        ConnectionProperties: ConnectionPropertiesTypeDef = ...
     ) -> CreateOutboundConnectionResponseTypeDef:
         """
         Creates a new cross-cluster search connection from a source Amazon OpenSearch
-        Service domain to a destination domain.
+        Service domain to a destination
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#create_outbound_connection)
@@ -248,7 +267,7 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         PackageName: str,
-        PackageType: Literal["TXT-DICTIONARY"],
+        PackageType: PackageTypeType,
         PackageSource: PackageSourceTypeDef,
         PackageDescription: str = ...
     ) -> CreatePackageResponseTypeDef:
@@ -282,7 +301,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DeleteInboundConnectionResponseTypeDef:
         """
         Allows the destination Amazon OpenSearch Service domain owner to delete an
-        existing inbound cross-cluster search connection.
+        existing inbound cross-cluster search
+        connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_inbound_connection)
@@ -293,7 +313,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DeleteOutboundConnectionResponseTypeDef:
         """
         Allows the source Amazon OpenSearch Service domain owner to delete an existing
-        outbound cross-cluster search connection.
+        outbound cross-cluster search
+        connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_outbound_connection)
@@ -318,7 +339,8 @@ class OpenSearchServiceClient(BaseClient):
     def describe_domain(self, *, DomainName: str) -> DescribeDomainResponseTypeDef:
         """
         Describes the domain configuration for the specified Amazon OpenSearch Service
-        domain, including the domain ID, domain service endpoint, and domain ARN.
+        domain, including the domain ID, domain service endpoint, and domain
+        ARN.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain)
@@ -329,7 +351,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
         Returns the list of optimizations that Auto-Tune has made to an Amazon
-        OpenSearch Service domain.
+        OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_auto_tunes)
@@ -340,7 +363,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeDomainChangeProgressResponseTypeDef:
         """
         Returns information about the current blue/green deployment happening on an
-        Amazon OpenSearch Service domain.
+        Amazon OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_change_progress)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_change_progress)
@@ -354,21 +378,56 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_config)
         """
 
+    def describe_domain_health(self, *, DomainName: str) -> DescribeDomainHealthResponseTypeDef:
+        """
+        Returns information about domain and node health, the standby Availability
+        Zone, number of nodes per Availability Zone, and shard count per
+        node.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_health)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_health)
+        """
+
+    def describe_domain_nodes(self, *, DomainName: str) -> DescribeDomainNodesResponseTypeDef:
+        """
+        Returns information about domain and nodes, including data nodes, master nodes,
+        ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and
+        node
+        states.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_nodes)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_nodes)
+        """
+
     def describe_domains(self, *, DomainNames: Sequence[str]) -> DescribeDomainsResponseTypeDef:
         """
         Returns domain configuration information about the specified Amazon OpenSearch
-        Service domains.
+        Service
+        domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domains)
         """
 
+    def describe_dry_run_progress(
+        self, *, DomainName: str, DryRunId: str = ..., LoadDryRunConfig: bool = ...
+    ) -> DescribeDryRunProgressResponseTypeDef:
+        """
+        Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch
+        Service
+        domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_dry_run_progress)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_dry_run_progress)
+        """
+
     def describe_inbound_connections(
         self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeInboundConnectionsResponseTypeDef:
         """
         Lists all the inbound cross-cluster search connections for a destination
-        (remote) Amazon OpenSearch Service domain.
+        (remote) Amazon OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_inbound_connections)
@@ -383,7 +442,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeInstanceTypeLimitsResponseTypeDef:
         """
         Describes the instance count, storage, and master node limits for a given
-        OpenSearch or Elasticsearch version and instance type.
+        OpenSearch or Elasticsearch version and instance
+        type.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_instance_type_limits)
@@ -394,7 +454,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeOutboundConnectionsResponseTypeDef:
         """
         Lists all the outbound cross-cluster connections for a local (source) Amazon
-        OpenSearch Service domain.
+        OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_outbound_connections)
@@ -419,7 +480,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeReservedInstanceOfferingsResponseTypeDef:
         """
         Describes the available Amazon OpenSearch Service Reserved Instance offerings
-        for a given Region.
+        for a given
+        Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_reserved_instance_offerings)
@@ -430,7 +492,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> DescribeReservedInstancesResponseTypeDef:
         """
         Describes the Amazon OpenSearch Service instances that you have reserved in a
-        given Region.
+        given
+        Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_reserved_instances)
@@ -475,7 +538,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> GetCompatibleVersionsResponseTypeDef:
         """
         Returns a map of OpenSearch or Elasticsearch versions and the versions you can
-        upgrade them to.
+        upgrade them
+        to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_compatible_versions)
@@ -486,7 +550,9 @@ class OpenSearchServiceClient(BaseClient):
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
         Returns a list of Amazon OpenSearch Service package versions, along with their
-        creation time and commit message.
+        creation time, commit message, and plugin properties (if the package is a zip
+        plugin
+        package).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_package_version_history)
@@ -497,7 +563,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
         Retrieves the complete history of the last 10 upgrades performed on an Amazon
-        OpenSearch Service domain.
+        OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_upgrade_history)
@@ -506,7 +573,8 @@ class OpenSearchServiceClient(BaseClient):
     def get_upgrade_status(self, *, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
         Returns the most recent status of the last upgrade or upgrade eligibility check
-        performed on an Amazon OpenSearch Service domain.
+        performed on an Amazon OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_upgrade_status)
@@ -517,7 +585,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> ListDomainNamesResponseTypeDef:
         """
         Returns the names of all Amazon OpenSearch Service domains owned by the current
-        user in the active Region.
+        user in the active
+        Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_domain_names)
@@ -539,11 +608,14 @@ class OpenSearchServiceClient(BaseClient):
         EngineVersion: str,
         DomainName: str = ...,
         MaxResults: int = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        RetrieveAZs: bool = ...,
+        InstanceType: str = ...
     ) -> ListInstanceTypeDetailsResponseTypeDef:
         """
         Lists all instance types and available features for a given OpenSearch or
-        Elasticsearch version.
+        Elasticsearch
+        version.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_instance_type_details)
@@ -559,6 +631,16 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_packages_for_domain)
         """
 
+    def list_scheduled_actions(
+        self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListScheduledActionsResponseTypeDef:
+        """
+        Retrieves a list of configuration changes that are scheduled for a domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_scheduled_actions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_scheduled_actions)
+        """
+
     def list_tags(self, *, ARN: str) -> ListTagsResponseTypeDef:
         """
         Returns all resource tags for an Amazon OpenSearch Service domain.
@@ -572,7 +654,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> ListVersionsResponseTypeDef:
         """
         Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch
-        Service supports.
+        Service
+        supports.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_versions)
@@ -584,7 +667,8 @@ class OpenSearchServiceClient(BaseClient):
         """
         Retrieves information about each Amazon Web Services principal that is allowed
         to access a given Amazon OpenSearch Service domain through the use of an
-        interface VPC endpoint.
+        interface VPC
+        endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoint_access)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoint_access)
@@ -593,7 +677,8 @@ class OpenSearchServiceClient(BaseClient):
     def list_vpc_endpoints(self, *, NextToken: str = ...) -> ListVpcEndpointsResponseTypeDef:
         """
         Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current
-        Amazon Web Services account and Region.
+        Amazon Web Services account and
+        Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoints)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoints)
@@ -604,7 +689,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> ListVpcEndpointsForDomainResponseTypeDef:
         """
         Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a
-        particular domain.
+        particular
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoints_for_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoints_for_domain)
@@ -625,7 +711,8 @@ class OpenSearchServiceClient(BaseClient):
     ) -> RejectInboundConnectionResponseTypeDef:
         """
         Allows the remote Amazon OpenSearch Service domain owner to reject an inbound
-        cross-cluster connection request.
+        cross-cluster connection
+        request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#reject_inbound_connection)
@@ -642,14 +729,15 @@ class OpenSearchServiceClient(BaseClient):
     def revoke_vpc_endpoint_access(self, *, DomainName: str, Account: str) -> Dict[str, Any]:
         """
         Revokes access to an Amazon OpenSearch Service domain that was provided through
-        an interface VPC endpoint.
+        an interface VPC
+        endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.revoke_vpc_endpoint_access)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#revoke_vpc_endpoint_access)
         """
 
     def start_service_software_update(
-        self, *, DomainName: str
+        self, *, DomainName: str, ScheduleAt: ScheduleAtType = ..., DesiredStartTime: int = ...
     ) -> StartServiceSoftwareUpdateResponseTypeDef:
         """
         Schedules a service software update for an Amazon OpenSearch Service domain.
@@ -675,7 +763,10 @@ class OpenSearchServiceClient(BaseClient):
         NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = ...,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
         AutoTuneOptions: AutoTuneOptionsTypeDef = ...,
-        DryRun: bool = ...
+        DryRun: bool = ...,
+        DryRunMode: DryRunModeType = ...,
+        OffPeakWindowOptions: OffPeakWindowOptionsTypeDef = ...,
+        SoftwareUpdateOptions: SoftwareUpdateOptionsTypeDef = ...
     ) -> UpdateDomainConfigResponseTypeDef:
         """
         Modifies the cluster configuration of the specified Amazon OpenSearch Service
@@ -700,6 +791,22 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#update_package)
         """
 
+    def update_scheduled_action(
+        self,
+        *,
+        DomainName: str,
+        ActionID: str,
+        ActionType: ActionTypeType,
+        ScheduleAt: ScheduleAtType,
+        DesiredStartTime: int = ...
+    ) -> UpdateScheduledActionResponseTypeDef:
+        """
+        Reschedules a planned domain configuration change for a later time.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.update_scheduled_action)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#update_scheduled_action)
+        """
+
     def update_vpc_endpoint(
         self, *, VpcEndpointId: str, VpcOptions: VPCOptionsTypeDef
     ) -> UpdateVpcEndpointResponseTypeDef:
@@ -719,8 +826,8 @@ class OpenSearchServiceClient(BaseClient):
         AdvancedOptions: Mapping[str, str] = ...
     ) -> UpgradeDomainResponseTypeDef:
         """
-        Allows you to either upgrade your Amazon OpenSearch Service domain or perform an
-        upgrade eligibility check to a compatible version of OpenSearch or
+        Allows you to either upgrade your Amazon OpenSearch Service domain or perform
+        an upgrade eligibility check to a compatible version of OpenSearch or
         Elasticsearch.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
